1 new commit in galaxy-central:
https://bitbucket.org/galaxy/galaxy-central/changeset/21b645303c02/
changeset: 21b645303c02
user: jgoecks
date: 2011-12-22 19:54:33
summary: Set Cufflinks global model when upper quartile normalization is used.
affected #: 1 file
--
This is a commit notification from bitbucket.org. You are receiving
this because you have the service enabled, addressing the recipient of
this email.
1 new commit in galaxy-central:
https://bitbucket.org/galaxy/galaxy-central/changeset/d6d62cb3cf7e/
changeset: d6d62cb3cf7e
user: jgoecks
date: 2011-12-22 19:11:34
summary: Trackster: when running tools, replace track with group.
affected #: 1 file
diff -r 83756dd3d868aee6d319f0d1904a1dcdda12b5b9 -r d6d62cb3cf7ea7b7a11a5ca4caf4a85c50a31a93 static/scripts/trackster.js
--- a/static/scripts/trackster.js
+++ b/static/scripts/trackster.js
@@ -946,6 +946,20 @@
return false;
},
/**
+ * Replace one drawable with another.
+ */
+ replace_drawable: function(old_drawable, new_drawable, update_html) {
+ var index = this.drawables.indexOf(old_drawable);
+ if (index !== -1) {
+ this.drawables[index] = new_drawable;
+ if (update_html) {
+ old_drawable.container_div.replaceWith(new_drawable.container_div);
+ }
+ return true;
+ }
+ return false;
+ },
+ /**
* Remove drawable from this collection.
*/
remove_drawable: function(drawable) {
@@ -1002,7 +1016,11 @@
}
].concat(Drawable.prototype.action_icons_def),
build_container_div: function() {
- return $("<div/>").addClass("group").attr("id", "group_" + this.id).appendTo(this.container.content_div);
+ var container_div = $("<div/>").addClass("group").attr("id", "group_" + this.id);
+ if (this.container) {
+ this.container.content_div.append(container_div);
+ }
+ return container_div;
},
build_header_div: function() {
var header_div = $("<div/>").addClass("track-header");
@@ -1787,8 +1805,9 @@
// If track not in a group, create a group for it and add new track to group. If track
// already in group, add track to group.
if (current_track.container === view) {
- var group = new DrawableGroup(this.name, this.track.view, this.track.container);
- current_track.container.add_drawable(group);
+ // Create new group.
+ var group = new DrawableGroup(this.name, this.track.view);
+ current_track.container.replace_drawable(current_track, group, true);
// TODO: this is ugly way to move track from one container to another -- make this easier via
// a Drawable or DrawableCollection function.
current_track.container.remove_drawable(current_track);
@@ -1797,6 +1816,7 @@
container = group;
}
else {
+ // Use current group.
container = current_track.container;
}
Repository URL: https://bitbucket.org/galaxy/galaxy-central/
--
This is a commit notification from bitbucket.org. You are receiving
this because you have the service enabled, addressing the recipient of
this email.
1 new commit in galaxy-central:
https://bitbucket.org/galaxy/galaxy-central/changeset/83756dd3d868/
changeset: 83756dd3d868
user: jgoecks
date: 2011-12-22 16:43:17
summary: Trackster: use integer for dummy filter value rather than string because it is easier for client to decode.
affected #: 1 file
diff -r 356e8b9510a965d09226c450746dfa2ba267a42c -r 83756dd3d868aee6d319f0d1904a1dcdda12b5b9 lib/galaxy/visualization/tracks/data_providers.py
--- a/lib/galaxy/visualization/tracks/data_providers.py
+++ b/lib/galaxy/visualization/tracks/data_providers.py
@@ -1053,5 +1053,5 @@
payload.append( feature.attributes[col] )
else:
# Dummy value.
- payload.append( "na" )
+ payload.append( 0 )
return payload
Repository URL: https://bitbucket.org/galaxy/galaxy-central/
--
This is a commit notification from bitbucket.org. You are receiving
this because you have the service enabled, addressing the recipient of
this email.
1 new commit in galaxy-central:
https://bitbucket.org/galaxy/galaxy-central/changeset/bb5e05256c29/
changeset: bb5e05256c29
user: dan
date: 2011-12-20 21:40:07
summary: Add UCSC VCF external display application.
affected #: 2 files
diff -r f22a8a7bd077a118bcfa71430f345ff46873757f -r bb5e05256c2997892f5cac6b1998bbe90896372d datatypes_conf.xml.sample
--- a/datatypes_conf.xml.sample
+++ b/datatypes_conf.xml.sample
@@ -162,6 +162,7 @@
<converter file="vcf_to_vcf_bgzip_converter.xml" target_datatype="vcf_bgzip"/><converter file="vcf_to_tabix_converter.xml" target_datatype="tabix" depends_on="bgzip"/><converter file="vcf_to_summary_tree_converter.xml" target_datatype="summary_tree"/>
+ <display file="ucsc/vcf.xml" /><display file="igv/vcf.xml" /></datatype><datatype extension="bcf" type="galaxy.datatypes.binary:Binary" subclass="True"/>
diff -r f22a8a7bd077a118bcfa71430f345ff46873757f -r bb5e05256c2997892f5cac6b1998bbe90896372d display_applications/ucsc/vcf.xml
--- /dev/null
+++ b/display_applications/ucsc/vcf.xml
@@ -0,0 +1,17 @@
+<display id="ucsc_vcf" version="1.0.0" name="display at UCSC">
+ <!-- Load links from file: one line to one link -->
+ <dynamic_links from_file="tool-data/shared/ucsc/ucsc_build_sites.txt" skip_startswith="#" id="0" name="0">
+ <!-- Define parameters by column from file, allow splitting on builds -->
+ <dynamic_param name="site_id" value="0"/>
+ <dynamic_param name="ucsc_link" value="1"/>
+ <dynamic_param name="builds" value="2" split="True" separator="," />
+ <!-- Filter out some of the links based upon matching site_id to a Galaxy application configuration parameter and by dataset dbkey -->
+ <filter>${site_id in $APP.config.ucsc_display_sites}</filter>
+ <filter>${dataset.dbkey in $builds}</filter>
+ <!-- We define url and params as normal, but values defined in dynamic_param are available by specified name -->
+ <url>${ucsc_link}db=${qp($bgzip_file.dbkey)}&hgt.customText=${qp($track.url)}</url>
+ <param type="data" name="bgzip_file" url="galaxy_${DATASET_HASH}.vcf.gz" format="vcf_bgzip" />
+ <param type="data" name="tabix_file" dataset="bgzip_file" url="galaxy_${DATASET_HASH}.vcf.gz.tbi" format="tabix" />
+ <param type="template" name="track" viewable="True">track type="vcfTabix" name="${bgzip_file.name.replace( '\\', '\\\\' ).replace( '"', '\\"' )}" bigDataUrl="${bgzip_file.url}" db="${bgzip_file.dbkey}"</param>
+ </dynamic_links>
+</display>
Repository URL: https://bitbucket.org/galaxy/galaxy-central/
--
This is a commit notification from bitbucket.org. You are receiving
this because you have the service enabled, addressing the recipient of
this email.
1 new commit in galaxy-central:
https://bitbucket.org/galaxy/galaxy-central/changeset/f22a8a7bd077/
changeset: f22a8a7bd077
user: greg
date: 2011-12-20 20:31:13
summary: Don't allow repository names to be changed if the repository has been cloned at least 1 time.
affected #: 1 file
diff -r 8458fa9dd5590e0890effaf04c50ba19013a280c -r f22a8a7bd077a118bcfa71430f345ff46873757f templates/webapps/community/repository/manage_repository.mako
--- a/templates/webapps/community/repository/manage_repository.mako
+++ b/templates/webapps/community/repository/manage_repository.mako
@@ -139,7 +139,14 @@
%endif
<div class="form-row"><label>Name:</label>
- <input name="repo_name" type="textfield" value="${repo_name}" size="40"/>
+ %if repository.times_downloaded > 0:
+ ${repo_name}
+ %else:
+ <input name="repo_name" type="textfield" value="${repo_name}" size="40"/>
+ %endif
+ <div class="toolParamHelp" style="clear: both;">
+ Repository names cannot be changed if the repository has been cloned.
+ </div><div style="clear: both"></div></div><div class="form-row">
Repository URL: https://bitbucket.org/galaxy/galaxy-central/
diff -r d6d62cb3cf7ea7b7a11a5ca4caf4a85c50a31a93 -r 21b645303c0221690a0114b021cd5e706b0c917a tools/ngs_rna/cufflinks_wrapper.py
--- a/tools/ngs_rna/cufflinks_wrapper.py
+++ b/tools/ngs_rna/cufflinks_wrapper.py
@@ -137,11 +137,11 @@
returncode = proc.wait()
tmp_stderr.close()
# Read standard error to get total map mass.
total_map_mass = -1
tmp_stderr = open( tmp_name, 'r' )
for line in tmp_stderr:
- if line.lower().find( "total map mass") >= 0:
+ if line.lower().find( "total map mass" ) >= 0 or line.lower().find( "upper quartile" ) >= 0:
total_map_mass = float( line.split(":")[1].strip() )
break
tmp_stderr.close()
@@ -137,11 +137,11 @@
returncode = proc.wait()
tmp_stderr.close()
- # Read standard error to get total map mass.
+ # Read standard error to get total map/upper quartile mass.
total_map_mass = -1
tmp_stderr = open( tmp_name, 'r' )
Repository URL: https://bitbucket.org/galaxy/galaxy-central/
--
This is a commit notification from bitbucket.org. You are receiving
this because you have the service enabled, addressing the recipient of
this email.